@@ -1,5 +1,3 @@
-# -*- coding: utf-8 -*-
-
 """
 The OsmApi module is a wrapper for the OpenStreetMap API.
 As such it provides an easy access to the functionality of the API.
@@ -49,19 +47,21 @@ class OsmApi:
     """
     Main class of osmapi, instanciate this class to use osmapi
     """
+
     def __init__(
-            self,
-            username=None,
-            password=None,
-            passwordfile=None,
-            appid="",
-            created_by="osmapi/%s" % __version__,
-            api="https://www.openstreetmap.org",
-            changesetauto=False,
-            changesetautotags={},
-            changesetautosize=500,
-            changesetautomulti=1,
-            session=None):
+        self,
+        username=None,
+        password=None,
+        passwordfile=None,
+        appid="",
+        created_by=f"osmapi/{__version__}",
+        api="https://www.openstreetmap.org",
+        changesetauto=False,
+        changesetautotags={},
+        changesetautosize=500,
+        changesetautomulti=1,
+        session=None,
+    ):
         """
         Initialized the OsmApi object.
 
@@ -102,7 +102,7 @@ class OsmApi:
         elif passwordfile:
             with open(passwordfile) as f:
                 pass_line = f.readline()
-            self._username = pass_line.split(":")[0].strip()
+            self._username = pass_line.partition(":")[0].strip()
 
         # Get password
         self._password = None
@@ -111,9 +111,9 @@ class OsmApi:
         elif passwordfile:
             with open(passwordfile) as f:
                 for line in f:
-                    line = line.strip().split(":", 1)
-                    if line[0] == self._username:
-                        self._password = line[1]
+                    key, _, value = line.strip().partition(":")
+                    if key == self._username:
+                        self._password = value
 
         # Changest informations
         # auto create and close changesets
@@ -131,13 +131,13 @@ class OsmApi:
         self._changesetautodata = []
 
         # Get API
-        self._api = api.strip('/')
+        self._api = api.strip("/")
 
         # Get created_by
         if not appid:
             self._created_by = created_by
         else:
-            self._created_by = "%s (%s)" % (appid, created_by)
+            self._created_by = f"{appid} ({created_by})"
 
         # Initialisation
         self._CurrentChangesetId = 0
@@ -148,17 +148,12 @@ class OsmApi:
         if self._username and self._password:
             auth = (self._username, self._password)
         self._session = http.OsmApiSession(
-            self._api,
-            self._created_by,
-            auth=auth,
-            session=self.http_session
+            self._api, self._created_by, auth=auth, session=self.http_session
         )
 
     def __enter__(self):
         self._session = http.OsmApiSession(
-            self._api,
-            self._created_by,
-            session=self.http_session
+            self._api, self._created_by, session=self.http_session
         )
         return self
 
@@ -257,10 +252,13 @@ class OsmApi:
 
         If the requested element has been deleted,
         `OsmApi.ElementDeletedApiError` is raised.
+
+        If the requested element can not be found,
+        `OsmApi.ElementNotFoundApiError` is raised.
         """
-        uri = "/api/0.6/node/%s" % (NodeId)
+        uri = f"/api/0.6/node/{NodeId}"
         if NodeVersion != -1:
-            uri += "/%s" % (NodeVersion)
+            uri += f"/{NodeVersion}"
         data = self._session._get(uri)
         data = dom.OsmResponseToDom(data, tag="node", single=True)
         return dom.DomParseNode(data)
@@ -389,6 +387,9 @@ class OsmApi:
 
         If the requested element has already been deleted,
         `OsmApi.ElementDeletedApiError` is raised.
+
+        If the requested element can not be found,
+        `OsmApi.ElementNotFoundApiError` is raised.
         """
         return self._do("delete", "node", NodeData)
 
@@ -405,7 +406,7 @@ class OsmApi:
 
         `NodeId` is the unique identifier of a node.
         """
-        uri = "/api/0.6/node/%s/history" % NodeId
+        uri = f"/api/0.6/node/{NodeId}/history"
         data = self._session._get(uri)
         nodes = dom.OsmResponseToDom(data, tag="node")
         result = {}
@@ -437,7 +438,7 @@ class OsmApi:
 
         The `NodeId` is a unique identifier for a node.
         """
-        uri = "/api/0.6/node/%d/ways" % NodeId
+        uri = f"/api/0.6/node/{NodeId}/ways"
         data = self._session._get(uri)
         ways = dom.OsmResponseToDom(data, tag="way", allow_empty=True)
         result = []
@@ -478,7 +479,7 @@ class OsmApi:
 
         The `NodeId` is a unique identifier for a node.
         """
-        uri = "/api/0.6/node/%d/relations" % NodeId
+        uri = f"/api/0.6/node/{NodeId}/relations"
         data = self._session._get(uri)
         relations = dom.OsmResponseToDom(data, tag="relation", allow_empty=True)
         result = []
@@ -503,7 +504,7 @@ class OsmApi:
         for multiple nodes.
         """
         node_list = ",".join([str(x) for x in NodeIdList])
-        uri = "/api/0.6/nodes?nodes=%s" % node_list
+        uri = f"/api/0.6/nodes?nodes={node_list}"
         data = self._session._get(uri)
         nodes = dom.OsmResponseToDom(data, tag="node")
         result = {}
@@ -538,10 +539,13 @@ class OsmApi:
 
         If the requested element has been deleted,
         `OsmApi.ElementDeletedApiError` is raised.
+
+        If the requested element can not be found,
+        `OsmApi.ElementNotFoundApiError` is raised.
         """
-        uri = "/api/0.6/way/%s" % (WayId)
+        uri = f"/api/0.6/way/{WayId}"
         if WayVersion != -1:
-            uri += "/%s" % (WayVersion)
+            uri += f"/{WayVersion}"
         data = self._session._get(uri)
         way = dom.OsmResponseToDom(data, tag="way", single=True)
         return dom.DomParseWay(way)
@@ -667,6 +671,9 @@ class OsmApi:
 
         If the requested element has already been deleted,
         `OsmApi.ElementDeletedApiError` is raised.
+
+        If the requested element can not be found,
+        `OsmApi.ElementNotFoundApiError` is raised.
         """
         return self._do("delete", "way", WayData)
 
@@ -683,7 +690,7 @@ class OsmApi:
 
         `WayId` is the unique identifier of a way.
         """
-        uri = "/api/0.6/way/%s/history" % (WayId)
+        uri = f"/api/0.6/way/{WayId}/history"
         data = self._session._get(uri)
         ways = dom.OsmResponseToDom(data, tag="way")
         result = {}
@@ -724,7 +731,7 @@ class OsmApi:
 
         The `WayId` is a unique identifier for a way.
         """
-        uri = "/api/0.6/way/%d/relations" % WayId
+        uri = f"/api/0.6/way/{WayId}/relations"
         data = self._session._get(uri)
         relations = dom.OsmResponseToDom(data, tag="relation", allow_empty=True)
         result = []
@@ -750,8 +757,11 @@ class OsmApi:
 
         If the requested element has been deleted,
         `OsmApi.ElementDeletedApiError` is raised.
+
+        If the requested element can not be found,
+        `OsmApi.ElementNotFoundApiError` is raised.
         """
-        uri = "/api/0.6/way/%s/full" % (WayId)
+        uri = f"/api/0.6/way/{WayId}/full"
         data = self._session._get(uri)
         return parser.ParseOsm(data)
 
@@ -770,7 +780,7 @@ class OsmApi:
         `WayIdList` is a list containing unique identifiers for multiple ways.
         """
         way_list = ",".join([str(x) for x in WayIdList])
-        uri = "/api/0.6/ways?ways=%s" % way_list
+        uri = f"/api/0.6/ways?ways={way_list}"
         data = self._session._get(uri)
         ways = dom.OsmResponseToDom(data, tag="way")
         result = {}
@@ -814,10 +824,13 @@ class OsmApi:
 
         If the requested element has been deleted,
         `OsmApi.ElementDeletedApiError` is raised.
+
+        If the requested element can not be found,
+        `OsmApi.ElementNotFoundApiError` is raised.
         """
-        uri = "/api/0.6/relation/%s" % (RelationId)
+        uri = f"/api/0.6/relation/{RelationId}"
         if RelationVersion != -1:
-            uri += "/%s" % (RelationVersion)
+            uri += f"/{RelationVersion}"
         data = self._session._get(uri)
         relation = dom.OsmResponseToDom(data, tag="relation", single=True)
         return dom.DomParseRelation(relation)
@@ -970,6 +983,9 @@ class OsmApi:
 
         If the requested element has already been deleted,
         `OsmApi.ElementDeletedApiError` is raised.
+
+        If the requested element can not be found,
+        `OsmApi.ElementNotFoundApiError` is raised.
         """
         return self._do("delete", "relation", RelationData)
 
@@ -986,7 +1002,7 @@ class OsmApi:
 
         `RelationId` is the unique identifier of a relation.
         """
-        uri = "/api/0.6/relation/%s/history" % (RelationId)
+        uri = f"/api/0.6/relation/{RelationId}/history"
         data = self._session._get(uri)
         relations = dom.OsmResponseToDom(data, tag="relation")
         result = {}
@@ -1028,7 +1044,7 @@ class OsmApi:
 
         The `RelationId` is a unique identifier for a relation.
         """
-        uri = "/api/0.6/relation/%d/relations" % RelationId
+        uri = f"/api/0.6/relation/{RelationId}/relations"
         data = self._session._get(uri)
         relations = dom.OsmResponseToDom(data, tag="relation", allow_empty=True)
         result = []
@@ -1060,6 +1076,9 @@ class OsmApi:
 
         If any relation (on any level) has been deleted,
         `OsmApi.ElementDeletedApiError` is raised.
+
+        If the requested element can not be found,
+        `OsmApi.ElementNotFoundApiError` is raised.
         """
         data = []
         todo = [RelationId]
@@ -1097,8 +1116,11 @@ class OsmApi:
 
         If the requested element has been deleted,
         `OsmApi.ElementDeletedApiError` is raised.
+
+        If the requested element can not be found,
+        `OsmApi.ElementNotFoundApiError` is raised.
         """
-        uri = "/api/0.6/relation/%s/full" % (RelationId)
+        uri = f"/api/0.6/relation/{RelationId}/full"
         data = self._session._get(uri)
         return parser.ParseOsm(data)
 
@@ -1118,7 +1140,7 @@ class OsmApi:
         for multiple relations.
         """
         relation_list = ",".join([str(x) for x in RelationIdList])
-        uri = "/api/0.6/relations?relations=%s" % relation_list
+        uri = f"/api/0.6/relations?relations={relation_list}"
         data = self._session._get(uri)
         relations = dom.OsmResponseToDom(data, tag="relation")
         result = {}
@@ -1163,7 +1185,7 @@ class OsmApi:
         # upload data to changeset
         autosize = self._changesetautosize
         for i in range(0, len(self._changesetautodata), autosize):
-            chunk = self._changesetautodata[i:i+autosize]
+            chunk = self._changesetautodata[i : i + autosize]
             self.ChangesetUpload(chunk)
         self._changesetautodata = []
         self.ChangesetClose()
@@ -1194,8 +1216,8 @@ class OsmApi:
         If `include_discussion` is set to `True` the changeset discussion
         will be available in the result.
         """
-        path = "/api/0.6/changeset/%s" % (ChangesetId)
-        if (include_discussion):
+        path = f"/api/0.6/changeset/{ChangesetId}"
+        if include_discussion:
             path += "?include_discussion=true"
         data = self._session._get(path)
         changeset = dom.OsmResponseToDom(data, tag="changeset", single=True)
@@ -1220,9 +1242,9 @@ class OsmApi:
             ChangesetTags["created_by"] = self._created_by
         try:
             self._session._put(
-                "/api/0.6/changeset/%s" % (self._CurrentChangesetId),
+                f"/api/0.6/changeset/{self._CurrentChangesetId}",
                 xmlbuilder._XmlBuild("changeset", {"tag": ChangesetTags}, data=self),
-                return_value=False
+                return_value=False,
             )
         except errors.ApiError as e:
             if e.status == 409:
@@ -1249,9 +1271,19 @@ class OsmApi:
             raise errors.ChangesetAlreadyOpenError("Changeset already opened")
         if "created_by" not in ChangesetTags:
             ChangesetTags["created_by"] = self._created_by
+
+        # check if someone tries to create a test changeset to PROD
+        if (
+            self._api == "https://www.openstreetmap.org"
+            and ChangesetTags.get("comment") == "My first test"
+        ):
+            raise errors.OsmApiError(
+                "DO NOT CREATE test changesets on the production server"
+            )
+
         result = self._session._put(
             "/api/0.6/changeset/create",
-            xmlbuilder._XmlBuild("changeset", {"tag": ChangesetTags}, data=self)
+            xmlbuilder._XmlBuild("changeset", {"tag": ChangesetTags}, data=self),
         )
         self._CurrentChangesetId = int(result)
         return self._CurrentChangesetId
@@ -1275,9 +1307,9 @@ class OsmApi:
             raise errors.NoChangesetOpenError("No changeset currently opened")
         try:
             self._session._put(
-                "/api/0.6/changeset/%s/close" % (self._CurrentChangesetId),
+                f"/api/0.6/changeset/{self._CurrentChangesetId}/close",
                 "",
-                return_value=False
+                return_value=False,
             )
             CurrentChangesetId = self._CurrentChangesetId
             self._CurrentChangesetId = 0
@@ -1308,28 +1340,27 @@ class OsmApi:
         `OsmApi.ChangesetClosedApiError` is raised.
         """
         data = ""
-        data += "<?xml version=\"1.0\" encoding=\"UTF-8\"?>\n"
-        data += "<osmChange version=\"0.6\" generator=\""
-        data += self._created_by + "\">\n"
+        data += '<?xml version="1.0" encoding="UTF-8"?>\n'
+        data += '<osmChange version="0.6" generator="'
+        data += self._created_by + '">\n'
         for change in ChangesData:
             data += "<" + change["action"] + ">\n"
             change["data"]["changeset"] = self._CurrentChangesetId
             data += xmlbuilder._XmlBuild(
-                change["type"],
-                change["data"],
-                False,
-                data=self
+                change["type"], change["data"], False, data=self
             ).decode("utf-8")
             data += "</" + change["action"] + ">\n"
         data += "</osmChange>"
         try:
             data = self._session._post(
-                "/api/0.6/changeset/%s/upload" % (self._CurrentChangesetId),
+                f"/api/0.6/changeset/{self._CurrentChangesetId}/upload",
                 data.encode("utf-8"),
-                forceAuth=True
+                forceAuth=True,
             )
         except errors.ApiError as e:
-            if e.status == 409 and re.search(r"The changeset .* was closed at .*", e.payload):
+            if e.status == 409 and re.search(
+                r"The changeset .* was closed at .*", e.payload
+            ):
                 raise errors.ChangesetClosedApiError(e.status, e.reason, e.payload)
             else:
                 raise
@@ -1339,17 +1370,15 @@ class OsmApi:
             data = [x for x in data.childNodes if x.nodeType == x.ELEMENT_NODE]
         except (xml.parsers.expat.ExpatError, IndexError) as e:
             raise errors.XmlResponseInvalidError(
-                "The XML response from the OSM API is invalid: %r" % e
+                f"The XML response from the OSM API is invalid: {e!r}"
             )
 
-        for i in range(len(ChangesData)):
-            if ChangesData[i]["action"] == "delete":
-                ChangesData[i]["data"].pop("version")
+        for item, change in zip(data, ChangesData):
+            if change["action"] == "delete":
+                change["data"].pop("version")
             else:
-                new_id = int(data[i].getAttribute("new_id"))
-                ChangesData[i]["data"]["id"] = new_id
-                new_version = int(data[i].getAttribute("new_version"))
-                ChangesData[i]["data"]["version"] = new_version
+                change["data"]["id"] = int(item.getAttribute("new_id"))
+                change["data"]["version"] = int(item.getAttribute("new_version"))
         return ChangesData
 
     def ChangesetDownload(self, ChangesetId):
@@ -1365,22 +1394,23 @@ class OsmApi:
                 'data': {}
             }
         """
-        uri = "/api/0.6/changeset/%s/download" % (ChangesetId)
+        uri = f"/api/0.6/changeset/{ChangesetId}/download"
         data = self._session._get(uri)
         return parser.ParseOsc(data)
 
     def ChangesetsGet(  # noqa
-            self,
-            min_lon=None,
-            min_lat=None,
-            max_lon=None,
-            max_lat=None,
-            userid=None,
-            username=None,
-            closed_after=None,
-            created_before=None,
-            only_open=False,
-            only_closed=False):
+        self,
+        min_lon=None,
+        min_lat=None,
+        max_lon=None,
+        max_lat=None,
+        userid=None,
+        username=None,
+        closed_after=None,
+        created_before=None,
+        only_open=False,
+        only_closed=False,
+    ):
         """
         Returns a dict with the id of the changeset as key
         matching all criteria:
@@ -1398,14 +1428,7 @@ class OsmApi:
         uri = "/api/0.6/changesets"
         params = {}
         if min_lon or min_lat or max_lon or max_lat:
-            params["bbox"] = ",".join(
-                [
-                    str(min_lon),
-                    str(min_lat),
-                    str(max_lon),
-                    str(max_lat)
-                ]
-            )
+            params["bbox"] = f"{min_lon},{min_lat},{max_lon},{max_lat}"
         if userid:
             params["user"] = userid
         if username:
@@ -1415,7 +1438,7 @@ class OsmApi:
         if created_before:
             if not closed_after:
                 closed_after = "1970-01-01T00:00:00Z"
-            params["time"] = "%s,%s" % (closed_after, created_before)
+            params["time"] = f"{closed_after},{created_before}"
         if only_open:
             params["open"] = 1
         if only_closed:
@@ -1463,12 +1486,10 @@ class OsmApi:
         If the changeset is already closed,
         `OsmApi.ChangesetClosedApiError` is raised.
         """
-        params = urllib.parse.urlencode({'text': comment})
+        params = urllib.parse.urlencode({"text": comment})
         try:
             data = self._session._post(
-                "/api/0.6/changeset/%s/comment" % (ChangesetId),
-                params,
-                forceAuth=True
+                f"/api/0.6/changeset/{ChangesetId}/comment", params, forceAuth=True
             )
         except errors.ApiError as e:
             if e.status == 409:
@@ -1507,9 +1528,7 @@ class OsmApi:
         """
         try:
             data = self._session._post(
-                "/api/0.6/changeset/%s/subscribe" % (ChangesetId),
-                None,
-                forceAuth=True
+                f"/api/0.6/changeset/{ChangesetId}/subscribe", None, forceAuth=True
             )
         except errors.ApiError as e:
             if e.status == 409:
@@ -1548,15 +1567,11 @@ class OsmApi:
         """
         try:
             data = self._session._post(
-                "/api/0.6/changeset/%s/unsubscribe" % (ChangesetId),
-                None,
-                forceAuth=True
+                f"/api/0.6/changeset/{ChangesetId}/unsubscribe", None, forceAuth=True
             )
-        except errors.ApiError as e:
-            if e.status == 404:
-                raise errors.NotSubscribedApiError(e.status, e.reason, e.payload)
-            else:
-                raise
+        except errors.ElementNotFoundApiError as e:
+            raise errors.NotSubscribedApiError(e.status, e.reason, e.payload)
+
         changeset = dom.OsmResponseToDom(data, tag="changeset", single=True)
         return dom.DomParseChangeset(changeset)
 
@@ -1564,14 +1579,7 @@ class OsmApi:
     # Notes                                          #
     ##################################################
 
-    def NotesGet(
-            self,
-            min_lon,
-            min_lat,
-            max_lon,
-            max_lat,
-            limit=100,
-            closed=7):
+    def NotesGet(self, min_lon, min_lat, max_lon, max_lat, limit=100, closed=7):
         """
         Returns a list of dicts of notes in the specified bounding box:
 
@@ -1600,8 +1608,9 @@ class OsmApi:
         All parameters are optional.
         """
         uri = (
-            "/api/0.6/notes?bbox=%f,%f,%f,%f&limit=%d&closed=%d"
-            % (min_lon, min_lat, max_lon, max_lat, limit, closed)
+            f"/api/0.6/notes?bbox="
+            f"{min_lon:f},{min_lat:f},{max_lon:f},{max_lat:f}"
+            f"&limit={limit}&closed={closed}"
         )
         data = self._session._get(uri)
         return parser.ParseNotes(data)
@@ -1624,16 +1633,44 @@ class OsmApi:
 
         `id` is the unique identifier of the note.
         """
-        uri = "/api/0.6/notes/%s" % (id)
+        uri = f"/api/0.6/notes/{id}"
         data = self._session._get(uri)
         noteElement = dom.OsmResponseToDom(data, tag="note", single=True)
         return dom.DomParseNote(noteElement)
 
     def NoteCreate(self, NoteData):
         """
-        Creates a note.
+        Creates a note based on the supplied `NoteData` dict:
+
+            #!python
+            {
+                'lat': latitude of note,
+                'lon': longitude of note,
+                'text': text of the note,
+            }
+
+        Returns updated `NoteData`:
+
+            #!python
+            {
+                'id': id of note,
+                'lat': latitude of note,
+                'lon': longitude of note,
+                'date_created': date when the note was created
+                'date_closed': date when the note was closed or None if it's open,
+                'status': status of the note (open or closed),
+                'comments': [
+                    {
+                        'date': date of the comment,
+                        'action': status of comment (opened, commented, closed),
+                        'text': text of the note,
+                        'html': html version of the text of the note,
+                        'uid': user id of the user creating this note or None
+                        'user': username of the user creating this note or None
+                    }
+                ]
+            }
 
-        Returns updated NoteData (without timestamp).
         """
         uri = "/api/0.6/notes"
         uri += "?" + urllib.parse.urlencode(NoteData)
@@ -1645,7 +1682,7 @@ class OsmApi:
 
         Returns the updated note.
         """
-        path = "/api/0.6/notes/%s/comment" % NoteId
+        path = f"/api/0.6/notes/{NoteId}/comment"
         return self._NoteAction(path, comment)
 
     def NoteClose(self, NoteId, comment):
@@ -1657,7 +1694,7 @@ class OsmApi:
         If no authentication information are provided,
         `OsmApi.UsernamePasswordMissingError` is raised.
         """
-        path = "/api/0.6/notes/%s/close" % NoteId
+        path = f"/api/0.6/notes/{NoteId}/close"
         return self._NoteAction(path, comment, optionalAuth=False)
 
     def NoteReopen(self, NoteId, comment):
@@ -1671,8 +1708,11 @@ class OsmApi:
 
         If the requested element has been deleted,
         `OsmApi.ElementDeletedApiError` is raised.
+
+        If the requested element can not be found,
+        `OsmApi.ElementNotFoundApiError` is raised.
         """
-        path = "/api/0.6/notes/%s/reopen" % NoteId
+        path = f"/api/0.6/notes/{NoteId}/reopen"
         return self._NoteAction(path, comment, optionalAuth=False)
 
     def NotesSearch(self, query, limit=100, closed=7):
@@ -1688,9 +1728,9 @@ class OsmApi:
         """
         uri = "/api/0.6/notes/search"
         params = {}
-        params['q'] = query
-        params['limit'] = limit
-        params['closed'] = closed
+        params["q"] = query
+        params["limit"] = limit
+        params["closed"] = closed
         uri += "?" + urllib.parse.urlencode(params)
         data = self._session._get(uri)
 
@@ -1705,13 +1745,13 @@ class OsmApi:
         uri = path
         if comment is not None:
             params = {}
-            params['text'] = comment
+            params["text"] = comment
             uri += "?" + urllib.parse.urlencode(params)
         try:
             result = self._session._post(uri, None, optionalAuth=optionalAuth)
         except errors.ApiError as e:
-            if e.status == 404:
-                raise errors.NoteClosedApiError(e.status, e.reason, e.payload)
+            if e.status == 409:
+                raise errors.NoteAlreadyClosedApiError(e.status, e.reason, e.payload)
             else:
                 raise
 
@@ -1735,10 +1775,7 @@ class OsmApi:
                 data: {}
             }
         """
-        uri = (
-            "/api/0.6/map?bbox=%f,%f,%f,%f"
-            % (min_lon, min_lat, max_lon, max_lat)
-        )
+        uri = f"/api/0.6/map?bbox={min_lon:f},{min_lat:f},{max_lon:f},{max_lat:f}"
         data = self._session._get(uri)
         return parser.ParseOsm(data)
 
@@ -1763,11 +1800,9 @@ class OsmApi:
 
     def _do(self, action, OsmType, OsmData):
         if self._changesetauto:
-            self._changesetautodata.append({
-                "action": action,
-                "type": OsmType,
-                "data": OsmData
-            })
+            self._changesetautodata.append(
+                {"action": action, "type": OsmType, "data": OsmData}
+            )
             self._changesetautoflush()
             return None
         else:
@@ -1783,21 +1818,23 @@ class OsmApi:
         OsmData["changeset"] = self._CurrentChangesetId
         if action == "create":
             if OsmData.get("id", -1) > 0:
-                raise errors.OsmTypeAlreadyExistsError(
-                    "This %s already exists" % OsmType
-                )
+                raise errors.OsmTypeAlreadyExistsError(f"This {OsmType} already exists")
             try:
                 result = self._session._put(
-                    "/api/0.6/%s/create" % OsmType,
-                    xmlbuilder._XmlBuild(OsmType, OsmData, data=self)
+                    f"/api/0.6/{OsmType}/create",
+                    xmlbuilder._XmlBuild(OsmType, OsmData, data=self),
                 )
             except errors.ApiError as e:
-                if e.status == 409 and re.search(r"The changeset .* was closed at .*", e.payload):
+                if e.status == 409 and re.search(
+                    r"The changeset .* was closed at .*", e.payload
+                ):
                     raise errors.ChangesetClosedApiError(e.status, e.reason, e.payload)
                 elif e.status == 409:
                     raise errors.VersionMismatchApiError(e.status, e.reason, e.payload)
                 elif e.status == 412:
-                    raise errors.PreconditionFailedApiError(e.status, e.reason, e.payload)
+                    raise errors.PreconditionFailedApiError(
+                        e.status, e.reason, e.payload
+                    )
                 else:
                     raise
             OsmData["id"] = int(result.strip())
@@ -1806,17 +1843,21 @@ class OsmApi:
         elif action == "modify":
             try:
                 result = self._session._put(
-                    "/api/0.6/%s/%s" % (OsmType, OsmData["id"]),
-                    xmlbuilder._XmlBuild(OsmType, OsmData, data=self)
+                    f"/api/0.6/{OsmType}/{OsmData['id']}",
+                    xmlbuilder._XmlBuild(OsmType, OsmData, data=self),
                 )
             except errors.ApiError as e:
                 logger.error(e.reason)
-                if e.status == 409 and re.search(r"The changeset .* was closed at .*", e.payload):
+                if e.status == 409 and re.search(
+                    r"The changeset .* was closed at .*", e.payload
+                ):
                     raise errors.ChangesetClosedApiError(e.status, e.reason, e.payload)
                 elif e.status == 409:
                     raise errors.VersionMismatchApiError(e.status, e.reason, e.payload)
                 elif e.status == 412:
-                    raise errors.PreconditionFailedApiError(e.status, e.reason, e.payload)
+                    raise errors.PreconditionFailedApiError(
+                        e.status, e.reason, e.payload
+                    )
                 else:
                     raise
             OsmData["version"] = int(result.strip())
@@ -1824,16 +1865,20 @@ class OsmApi:
         elif action == "delete":
             try:
                 result = self._session._delete(
-                    "/api/0.6/%s/%s" % (OsmType, OsmData["id"]),
-                    xmlbuilder._XmlBuild(OsmType, OsmData, data=self)
+                    f"/api/0.6/{OsmType}/{OsmData['id']}",
+                    xmlbuilder._XmlBuild(OsmType, OsmData, data=self),
                 )
             except errors.ApiError as e:
-                if e.status == 409 and re.search(r"The changeset .* was closed at .*", e.payload):
+                if e.status == 409 and re.search(
+                    r"The changeset .* was closed at .*", e.payload
+                ):
                     raise errors.ChangesetClosedApiError(e.status, e.reason, e.payload)
                 elif e.status == 409:
                     raise errors.VersionMismatchApiError(e.status, e.reason, e.payload)
                 elif e.status == 412:
-                    raise errors.PreconditionFailedApiError(e.status, e.reason, e.payload)
+                    raise errors.PreconditionFailedApiError(
+                        e.status, e.reason, e.payload
+                    )
                 else:
                     raise
             OsmData["version"] = int(result.strip())
@@ -1842,13 +1887,12 @@ class OsmApi:
 
     def _changesetautoflush(self, force=False):
         autosize = self._changesetautosize
-        while ((len(self._changesetautodata) >= autosize) or
-                (force and self._changesetautodata)):
+        while (len(self._changesetautodata) >= autosize) or (
+            force and self._changesetautodata
+        ):
             if self._changesetautocpt == 0:
                 self.ChangesetCreate(self._changesetautotags)
-            self.ChangesetUpload(
-                self._changesetautodata[:autosize]
-            )
+            self.ChangesetUpload(self._changesetautodata[:autosize])
             self._changesetautodata = self._changesetautodata[autosize:]
             self._changesetautocpt += 1
             if self._changesetautocpt == self._changesetautomulti:
